@@ -1,3 +1,5 @@
+from __future__ import with_statement
+
 from constants import *
 import inotifyx
 import subprocess
@@ -100,12 +102,12 @@ class ChangeMonitor(object):
             # Block until events arrive.
             events = inotifyx.get_events(self.fd)
 
-            # Continue collecting events for the delay period.  This
-            # allows events that occur close to the trigger event to be
-            # collected now rather than causing another run immediately
-            # after this run.
-            end = time.time() + self.delay
-            while time.time() < end:
+            # Collect any events that occur within the delay period.
+            # This allows events that occur close to the trigger event
+            # to be collected now rather than causing another run
+            # immediately after this run.
+            if self.delay:
+                time.sleep(self.delay)
                 events.extend(inotifyx.get_events(self.fd, 0))
 
             # Filter to events that are white listed.
